// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KAUTH_VERSION_H
#define KAUTH_VERSION_H

#define KAUTH_VERSION_STRING "5.98.0"
#define KAUTH_VERSION_MAJOR 5
#define KAUTH_VERSION_MINOR 98
#define KAUTH_VERSION_PATCH 0
#define KAUTH_VERSION ((5<<16)|(98<<8)|(0))

#endif
